@@ -21,6 +21,7 @@ package nodejs
 import (
 	"bytes"
 	"encoding/json"
+	"errors"
 	"fmt"
 	"io"
 	"path"
@@ -31,8 +32,6 @@ import (
 	"strings"
 	"unicode"
 
-	"github.com/pkg/errors"
-
 	"github.com/pulumi/pulumi/pkg/v3/codegen"
 	"github.com/pulumi/pulumi/pkg/v3/codegen/internal/tstypes"
 	"github.com/pulumi/pulumi/pkg/v3/codegen/schema"
@@ -443,7 +442,7 @@ func tsPrimitiveValue(value interface{}) (string, error) {
 	case reflect.String:
 		return fmt.Sprintf("%q", v.String()), nil
 	default:
-		return "", errors.Errorf("unsupported default value of type %T", value)
+		return "", fmt.Errorf("unsupported default value of type %T", value)
 	}
 }
 
@@ -1404,6 +1403,11 @@ func (mod *modContext) sdkImports(nested, utilities bool) []string {
 func (mod *modContext) genTypes() (string, string) {
 	externalImports, imports := codegen.NewStringSet(), map[string]codegen.StringSet{}
 	for _, t := range mod.types {
+		if t.IsOverlay {
+			// This type is generated by the provider, so no further action is required.
+			continue
+		}
+
 		mod.getImports(t, externalImports, imports)
 	}
 
@@ -1454,6 +1458,11 @@ func (mod *modContext) getNamespaces() map[string]*namespace {
 	}
 
 	for _, t := range mod.types {
+		if t.IsOverlay {
+			// This type is generated by the provider, so no further action is required.
+			continue
+		}
+
 		modName := mod.pkg.TokenToModule(t.Token)
 		if override, ok := mod.modToPkg[modName]; ok {
 			modName = override
@@ -1599,6 +1608,11 @@ func (mod *modContext) gen(fs fs) error {
 
 	// Resources
 	for _, r := range mod.resources {
+		if r.IsOverlay {
+			// This resource code is generated by the provider, so no further action is required.
+			continue
+		}
+
 		externalImports, imports := codegen.NewStringSet(), map[string]codegen.StringSet{}
 		referencesNestedTypes := mod.getImportsForResource(r, externalImports, imports, r)
 
@@ -1615,6 +1629,11 @@ func (mod *modContext) gen(fs fs) error {
 
 	// Functions
 	for _, f := range mod.functions {
+		if f.IsOverlay {
+			// This function code is generated by the provider, so no further action is required.
+			continue
+		}
+
 		externalImports, imports := codegen.NewStringSet(), map[string]codegen.StringSet{}
 		referencesNestedTypes := mod.getImports(f, externalImports, imports)
 
@@ -1770,6 +1789,11 @@ func (mod *modContext) genResourceModule(w io.Writer) {
 	} else {
 		registrations, first := codegen.StringSet{}, true
 		for _, r := range mod.resources {
+			if r.IsOverlay {
+				// This resource code is generated by the provider, so no further action is required.
+				continue
+			}
+
 			if r.IsProvider {
 				contract.Assert(provider == nil)
 				provider = r
@@ -1792,6 +1816,11 @@ func (mod *modContext) genResourceModule(w io.Writer) {
 		fmt.Fprintf(w, "        switch (type) {\n")
 
 		for _, r := range mod.resources {
+			if r.IsOverlay {
+				// This resource code is generated by the provider, so no further action is required.
+				continue
+			}
+
 			if r.IsProvider {
 				continue
 			}
@@ -2107,6 +2136,11 @@ func generateModuleContextMap(tool string, pkg *schema.Package, extraFiles map[s
 	})
 
 	scanResource := func(r *schema.Resource) {
+		if r.IsOverlay {
+			// This resource code is generated by the provider, so no further action is required.
+			return
+		}
+
 		mod := getModFromToken(r.Token)
 		mod.resources = append(mod.resources, r)
 		visitObjectTypes(r.Properties, func(t *schema.ObjectType) {
@@ -2166,9 +2200,11 @@ func generateModuleContextMap(tool string, pkg *schema.Package, extraFiles map[s
 		case *schema.ObjectType:
 			types.types = append(types.types, typ)
 		case *schema.EnumType:
-			info.ContainsEnums = true
-			mod := getModFromToken(typ.Token)
-			mod.enums = append(mod.enums, typ)
+			if !typ.IsOverlay {
+				info.ContainsEnums = true
+				mod := getModFromToken(typ.Token)
+				mod.enums = append(mod.enums, typ)
+			}
 		default:
 			continue
 		}
@@ -2225,6 +2261,11 @@ func LanguageResources(pkg *schema.Package) (map[string]LanguageResource, error)
 
 	for modName, mod := range modules {
 		for _, r := range mod.resources {
+			if r.IsOverlay {
+				// This resource code is generated by the provider, so no further action is required.
+				continue
+			}
+
 			packagePath := strings.Replace(modName, "/", ".", -1)
 			lr := LanguageResource{
 				Resource: r,
