@@ -52,6 +52,11 @@ namespace Pulumi.Automation
         /// </summary>
         public Workspace Workspace { get; }
 
+        /// <summary>
+        /// A module for editing the Stack's state.
+        /// </summary>
+        public WorkspaceStackState State { get; }
+
         /// <summary>
         /// Creates a new stack using the given workspace, and stack name.
         /// It fails if a stack with that name already exists.
@@ -115,6 +120,7 @@ namespace Pulumi.Automation
         {
             this.Name = name;
             this.Workspace = workspace;
+            this.State = new WorkspaceStackState(this);
 
             this._readyTask = mode switch
             {
@@ -644,7 +650,7 @@ namespace Pulumi.Automation
         public async Task CancelAsync(CancellationToken cancellationToken = default)
             => await this.Workspace.RunCommandAsync(new[] { "cancel", "--stack", this.Name, "--yes" }, cancellationToken).ConfigureAwait(false);
 
-        private async Task<CommandResult> RunCommandAsync(
+        internal async Task<CommandResult> RunCommandAsync(
             IList<string> args,
             Action<string>? onStandardOutput,
             Action<string>? onStandardError,
