@@ -1,4 +1,4 @@
-﻿// Copyright 2016-2019, Pulumi Corporation
+﻿// Copyright 2016-2021, Pulumi Corporation
 
 using System;
 using System.Collections;
@@ -21,7 +21,7 @@ namespace Pulumi.Serialization
 
         public Serializer(bool excessiveDebugOutput)
         {
-            this.DependentResources = new HashSet<Resource>();
+            DependentResources = new HashSet<Resource>();
             _excessiveDebugOutput = excessiveDebugOutput;
         }
 
@@ -39,7 +39,7 @@ namespace Pulumi.Serialization
         /// <item><see cref="Asset"/>s</item>
         /// <item><see cref="Archive"/>s</item>
         /// <item><see cref="Resource"/>s</item>
-        /// <item><see cref="ResourceArgs"/>s</item>
+        /// <item><see cref="ResourceArgs"/></item>
         /// <item><see cref="JsonElement"/></item>
         /// </list>
         /// Additionally, other more complex objects can be serialized as long as they are built
@@ -67,7 +67,7 @@ namespace Pulumi.Serialization
         /// </list>
         /// No other result type are allowed to be returned.
         /// </summary>
-        public async Task<object?> SerializeAsync(string ctx, object? prop, bool keepResources)
+        public async Task<object?> SerializeAsync(string ctx, object? prop, bool keepResources, bool keepOutputValues = false)
         {
             // IMPORTANT:
             // IMPORTANT: Keep this in sync with serializesPropertiesSync in invoke.ts
@@ -87,10 +87,15 @@ namespace Pulumi.Serialization
             }
 
             if (prop is InputArgs args)
-                return await SerializeInputArgsAsync(ctx, args, keepResources).ConfigureAwait(false);
+            {
+                return await SerializeInputArgsAsync(ctx, args, keepResources, keepOutputValues).ConfigureAwait(false);
+            }
 
             if (prop is AssetOrArchive assetOrArchive)
+            {
+                // There's no need to pass keepOutputValues when serializing assets or archives.
                 return await SerializeAssetOrArchiveAsync(ctx, assetOrArchive, keepResources).ConfigureAwait(false);
+            }
 
             if (prop is Task)
             {
@@ -105,7 +110,7 @@ $"Tasks are not allowed inside ResourceArgs. Please wrap your Task in an Output:
                     Log.Debug($"Serialize property[{ctx}]: Recursing into IInput");
                 }
 
-                return await SerializeAsync(ctx, input.ToOutput(), keepResources).ConfigureAwait(false);
+                return await SerializeAsync(ctx, input.ToOutput(), keepResources, keepOutputValues).ConfigureAwait(false);
             }
 
             if (prop is IUnion union)
@@ -115,7 +120,7 @@ $"Tasks are not allowed inside ResourceArgs. Please wrap your Task in an Output:
                     Log.Debug($"Serialize property[{ctx}]: Recursing into IUnion");
                 }
 
-                return await SerializeAsync(ctx, union.Value, keepResources).ConfigureAwait(false);
+                return await SerializeAsync(ctx, union.Value, keepResources, keepOutputValues).ConfigureAwait(false);
             }
 
             if (prop is JsonElement element)
@@ -134,9 +139,9 @@ $"Tasks are not allowed inside ResourceArgs. Please wrap your Task in an Output:
                 {
                     Log.Debug($"Serialize property[{ctx}]: Recursing into Output");
                 }
-
                 var data = await output.GetDataAsync().ConfigureAwait(false);
-                this.DependentResources.AddRange(data.Resources);
+                DependentResources.AddRange(data.Resources);
+                var propResources = new HashSet<Resource>(data.Resources);
 
                 // When serializing an Output, we will either serialize it as its resolved value or the "unknown value"
                 // sentinel. We will do the former for all outputs created directly by user code (such outputs always
@@ -144,15 +149,56 @@ $"Tasks are not allowed inside ResourceArgs. Please wrap your Task in an Output:
                 var isKnown = data.IsKnown;
                 var isSecret = data.IsSecret;
 
+                var valueSerializer = new Serializer(_excessiveDebugOutput);
+                var value = await valueSerializer.SerializeAsync($"{ctx}.id", data.Value, keepResources, keepOutputValues: false).ConfigureAwait(false);
+                var promiseDeps = valueSerializer.DependentResources;
+                DependentResources.UnionWith(promiseDeps);
+                propResources.UnionWith(promiseDeps);
+
+                if (keepOutputValues)
+                {
+                    if (isKnown && !isSecret && propResources.Count == 0)
+                    {
+                        return value;
+                    }
+
+                    var urnDeps = new HashSet<Resource>();
+                    foreach (var resource in propResources)
+                    {
+                        var urnSerializer = new Serializer(_excessiveDebugOutput);
+                        await urnSerializer.SerializeAsync($"{ctx} dependency", resource.Urn, keepResources, keepOutputValues: false).ConfigureAwait(false);
+                        urnDeps.UnionWith(urnSerializer.DependentResources);
+                    }
+                    DependentResources.UnionWith(urnDeps);
+                    propResources.UnionWith(urnDeps);
+
+                    var dependencies = await Deployment.GetAllTransitivelyReferencedResourceUrnsAsync(propResources).ConfigureAwait(false);
+                    var builder = ImmutableDictionary.CreateBuilder<string, object?>();
+                    builder.Add(Constants.SpecialSigKey, Constants.SpecialOutputValueSig);
+                    if (isKnown)
+                    {
+                        builder.Add(Constants.ValueName, value);
+                    }
+                    if (isSecret)
+                    {
+                        builder.Add(Constants.SecretName, isSecret);
+                    }
+                    if (dependencies.Count > 0)
+                    {
+                        builder.Add(Constants.DependenciesName,
+                            dependencies.OrderBy(x => x, StringComparer.Ordinal).ToImmutableArray<object>());
+                    }
+                    return builder.ToImmutable();
+                }
+
                 if (!isKnown)
                     return Constants.UnknownValue;
 
-                var value = await SerializeAsync($"{ctx}.id", data.Value, keepResources).ConfigureAwait(false);
                 if (isSecret)
                 {
                     var builder = ImmutableDictionary.CreateBuilder<string, object?>();
                     builder.Add(Constants.SpecialSigKey, Constants.SpecialSecretSig);
-                    builder.Add(Constants.SecretValueName, value);
+                    builder.Add(Constants.ValueName, value);
                     return builder.ToImmutable();
                 }
 
@@ -167,12 +213,12 @@ $"Tasks are not allowed inside ResourceArgs. Please wrap your Task in an Output:
                     Log.Debug($"Serialize property[{ctx}]: Encountered CustomResource");
                 }
 
-                this.DependentResources.Add(customResource);
+                DependentResources.Add(customResource);
 
-                var id = await SerializeAsync($"{ctx}.id", customResource.Id, keepResources).ConfigureAwait(false);
+                var id = await SerializeAsync($"{ctx}.id", customResource.Id, keepResources, keepOutputValues: false).ConfigureAwait(false);
                 if (keepResources)
                 {
-                    var urn = await SerializeAsync($"{ctx}.urn", customResource.Urn, keepResources).ConfigureAwait(false);
+                    var urn = await SerializeAsync($"{ctx}.urn", customResource.Urn, keepResources, keepOutputValues: false).ConfigureAwait(false);
                     var builder = ImmutableDictionary.CreateBuilder<string, object?>();
                     builder.Add(Constants.SpecialSigKey, Constants.SpecialResourceSig);
                     builder.Add(Constants.ResourceUrnName, urn);
@@ -206,7 +252,7 @@ $"Tasks are not allowed inside ResourceArgs. Please wrap your Task in an Output:
                     Log.Debug($"Serialize property[{ctx}]: Encountered ComponentResource");
                 }
 
-                var urn = await SerializeAsync($"{ctx}.urn", componentResource.Urn, keepResources).ConfigureAwait(false);
+                var urn = await SerializeAsync($"{ctx}.urn", componentResource.Urn, keepResources, keepOutputValues: false).ConfigureAwait(false);
                 if (keepResources)
                 {
                     var builder = ImmutableDictionary.CreateBuilder<string, object?>();
@@ -218,10 +264,14 @@ $"Tasks are not allowed inside ResourceArgs. Please wrap your Task in an Output:
             }
 
             if (prop is IDictionary dictionary)
-                return await SerializeDictionaryAsync(ctx, dictionary, keepResources).ConfigureAwait(false);
+            {
+                return await SerializeDictionaryAsync(ctx, dictionary, keepResources, keepOutputValues).ConfigureAwait(false);
+            }
 
             if (prop is IList list)
-                return await SerializeListAsync(ctx, list, keepResources).ConfigureAwait(false);
+            {
+                return await SerializeListAsync(ctx, list, keepResources, keepOutputValues).ConfigureAwait(false);
+            }
 
             if (prop is Enum e && e.GetTypeCode() == TypeCode.Int32)
             {
@@ -257,27 +307,27 @@ $"Tasks are not allowed inside ResourceArgs. Please wrap your Task in an Output:
                 case JsonValueKind.False:
                     return element.GetBoolean();
                 case JsonValueKind.Array:
-                {
-                    var result = ImmutableArray.CreateBuilder<object?>();
-                    var index = 0;
-                    foreach (var child in element.EnumerateArray())
                     {
-                        result.Add(SerializeJson($"{ctx}[{index}]", child));
-                        index++;
-                    }
+                        var result = ImmutableArray.CreateBuilder<object?>();
+                        var index = 0;
+                        foreach (var child in element.EnumerateArray())
+                        {
+                            result.Add(SerializeJson($"{ctx}[{index}]", child));
+                            index++;
+                        }
 
-                    return result.ToImmutable();
-                }
+                        return result.ToImmutable();
+                    }
                 case JsonValueKind.Object:
-                {
-                    var result = ImmutableDictionary.CreateBuilder<string, object?>();
-                    foreach (var x in element.EnumerateObject())
                     {
-                        result[x.Name] = SerializeJson($"{ctx}.{x.Name}", x.Value);
-                    }
+                        var result = ImmutableDictionary.CreateBuilder<string, object?>();
+                        foreach (var x in element.EnumerateObject())
+                        {
+                            result[x.Name] = SerializeJson($"{ctx}.{x.Name}", x.Value);
+                        }
 
-                    return result.ToImmutable();
-                }
+                        return result.ToImmutable();
+                    }
                 default:
                     throw new InvalidOperationException($"Unknown {nameof(JsonElement)}.{nameof(JsonElement.ValueKind)}: {element.ValueKind}");
             }
@@ -296,7 +346,7 @@ $"Tasks are not allowed inside ResourceArgs. Please wrap your Task in an Output:
                 throw new InvalidOperationException("Cannot serialize invalid archive");
 
             var propName = assetOrArchive.PropName;
-            var value = await SerializeAsync(ctx + "." + propName, assetOrArchive.Value, keepResources).ConfigureAwait(false);
+            var value = await SerializeAsync(ctx + "." + propName, assetOrArchive.Value, keepResources, keepOutputValues: false).ConfigureAwait(false);
 
             var builder = ImmutableDictionary.CreateBuilder<string, object>();
             builder.Add(Constants.SpecialSigKey, assetOrArchive.SigKey);
@@ -304,7 +354,7 @@ $"Tasks are not allowed inside ResourceArgs. Please wrap your Task in an Output:
             return builder.ToImmutable();
         }
 
-        private async Task<ImmutableDictionary<string, object>> SerializeInputArgsAsync(string ctx, InputArgs args, bool keepResources)
+        private async Task<ImmutableDictionary<string, object>> SerializeInputArgsAsync(string ctx, InputArgs args, bool keepResources, bool keepOutputValues)
         {
             if (_excessiveDebugOutput)
             {
@@ -312,10 +362,10 @@ $"Tasks are not allowed inside ResourceArgs. Please wrap your Task in an Output:
             }
 
             var dictionary = await args.ToDictionaryAsync().ConfigureAwait(false);
-            return await SerializeDictionaryAsync(ctx, dictionary, keepResources).ConfigureAwait(false);
+            return await SerializeDictionaryAsync(ctx, dictionary, keepResources, keepOutputValues).ConfigureAwait(false);
         }
 
-        private async Task<ImmutableArray<object?>> SerializeListAsync(string ctx, IList list, bool keepResources)
+        private async Task<ImmutableArray<object?>> SerializeListAsync(string ctx, IList list, bool keepResources, bool keepOutputValues)
         {
             if (_excessiveDebugOutput)
             {
@@ -330,13 +380,13 @@ $"Tasks are not allowed inside ResourceArgs. Please wrap your Task in an Output:
                     Log.Debug($"Serialize property[{ctx}]: array[{i}] element");
                 }
 
-                result.Add(await SerializeAsync($"{ctx}[{i}]", list[i], keepResources).ConfigureAwait(false));
+                result.Add(await SerializeAsync($"{ctx}[{i}]", list[i], keepResources, keepOutputValues).ConfigureAwait(false));
             }
 
             return result.MoveToImmutable();
         }
 
-        private async Task<ImmutableDictionary<string, object>> SerializeDictionaryAsync(string ctx, IDictionary dictionary, bool keepResources)
+        private async Task<ImmutableDictionary<string, object>> SerializeDictionaryAsync(string ctx, IDictionary dictionary, bool keepResources, bool keepOutputValues)
         {
             if (_excessiveDebugOutput)
             {
@@ -359,7 +409,7 @@ $"Tasks are not allowed inside ResourceArgs. Please wrap your Task in an Output:
 
                 // When serializing an object, we omit any keys with null values. This matches
                 // JSON semantics.
-                var v = await SerializeAsync($"{ctx}.{stringKey}", dictionary[stringKey], keepResources).ConfigureAwait(false);
+                var v = await SerializeAsync($"{ctx}.{stringKey}", dictionary[stringKey], keepResources, keepOutputValues).ConfigureAwait(false);
                 if (v != null)
                 {
                     result[stringKey] = v;
@@ -385,6 +435,27 @@ $"Tasks are not allowed inside ResourceArgs. Please wrap your Task in an Output:
                 _ => throw new InvalidOperationException("Unsupported value when converting to protobuf: " + value.GetType().FullName),
             };
 
+        /// <summary>
+        /// Detects encoded `Unknown` values in objects that conform
+        /// to the grammar returned by `SerializeAsync`.
+        ///
+        /// This possibly needs to be revisited to detect `Unknown`
+        /// values before `SerializeAsync` converts them, in the more
+        /// generic Output representation.
+        /// </summary>
+        internal static bool ContainsUnknowns(object? value)
+            => value switch
+            {
+                null => false,
+                int _ => false,
+                double d => false,
+                bool b => false,
+                string s => s == Constants.UnknownValue,
+                ImmutableArray<object> list => list.Any(v => ContainsUnknowns(v)),
+                ImmutableDictionary<string, object> dict => dict.AnyValues(v => ContainsUnknowns(v)),
+                _ => throw new InvalidOperationException("Unsupported value when converting to protobuf: " + value.GetType().FullName),
+            };
+
         /// <summary>
         /// Given a <see cref="ImmutableDictionary{TKey, TValue}"/> produced by <see cref="SerializeAsync"/>,
         /// produces the equivalent <see cref="Struct"/> that can be passed to the Pulumi engine.
